@@ -77,7 +77,7 @@ def checkDiskQuota():
         try:
             global partition_warning
             global partition_critical
-            quota_percent = re.findall(b'(\d+)%',output)[0]
+            quota_percent = re.findall(b'(\\d+)%',output)[0]
             if int(quota_percent) >= partition_warning:
                 logger.warning("WARNING: You're running low on disk space, Ganga may stall on launch or fail to download job output")
                 logger.warning("WARNING: Please free some disk space on: %s" % data_partition)
