@@ -95,7 +95,7 @@ class AppName(Gaudi):
 
         if (not self.package):
             self.package = available_packs(self.appname)
-        if self.appname is 'Vetra':
+        if self.appname == 'Vetra':
             self.lhcb_release_area = os.path.expandvars("$Vetra_release_area")
 
     def postprocess(self):
@@ -202,7 +202,7 @@ class AppName(Gaudi):
         extraopts = ''
         if self.extraopts:
             extraopts += self.extraopts
-            if self.extraopts.find('LHCbApp().XMLSummary') is -1:
+            if self.extraopts.find('LHCbApp().XMLSummary') == -1:
                 extraopts += "\nfrom Gaudi.Configuration import *"
                 extraopts += "\nfrom Configurables import LHCbApp"
                 extraopts += "\nLHCbApp().XMLSummary='summary.xml'"
@@ -225,9 +225,9 @@ class AppName(Gaudi):
             except Exception as err:
                 logger.debug("path Error:\n%s" % str(err))
                 debug_dir = tempfile.mkdtemp()
-
-            messages = err.message.split('###SPLIT###')
-            if len(messages) is 2:
+            err_message = err.args[0]
+            messages = err_message.split('###SPLIT###')
+            if len(messages) == 2:
                 stdout = open(debug_dir + '/gaudirun.stdout', 'w')
                 stderr = open(debug_dir + '/gaudirun.stderr', 'w')
                 stdout.write(messages[0])
@@ -239,7 +239,7 @@ class AppName(Gaudi):
                       'found in %s and %s respectively . ' % (stdout.name, stderr.name)
             else:
                 f = open(debug_dir + '/gaudirun.out', 'w')
-                f.write(err.message)
+                f.write(err_message)
                 f.close()
                 msg = 'Unable to parse job options! Please check options ' \
                       'files and extraopts. The output from gaudirun.py can be ' \
