@@ -8,8 +8,7 @@ from GangaCore.GPIDev.Lib.Tasks import ITask
 
 class ND280Task(ITask):
     """T2K add-ons for the Task framework"""
-    _schema = Schema(Version(1,0), dict(ITask._schema.datadict.items() + {
-        }.items()))
+    _schema = Schema(Version(1,0), dict(ITask._schema.datadict.items()))
 
     _category = 'tasks'
     _name = 'ND280Task'
